Attribute VB_Name = "MONWIN32"

'API functions for serial communication with Board TMS320F24x
'Motion Control Kit ( MCK240/MSK243 )
'*****************************************************************************
'*****************************************************************************
'Programmer: V.B.Technosoft
'    Date       : 12 July 1999
'    Version    : 1.1.002
'Status: OK
'****************************************************************************
'****************************************************************************/

Global Const PM = 0     'DSP program memory
Global Const DM = 1     'DSP data memory

'****************************************************************************
' General Declarations
'****************************************************************************/

'****************************************************************************
' Initialization Functions
'****************************************************************************/

Global Const B9600 = 12    'divisor LSbyte for 9600 baud
Global Const B19200 = 6    'divisor LSbyte for 19200 baud
Global Const B38400 = 3    'divisor LSbyte for 38400 baud
Global Const B56000 = 21    'divisor LSbyte for 56000 baud
Global Const B115200 = 10    'divisor LSbyte for 115200 baud

Declare Function set_baud_rate Lib "monwin32.dll" Alias "_set_baud_rate@4" (ByVal baud As Byte) As Long

'   Sends "Set baud rate" command to the MON24x command interpreter
'   and modifies the PC baud rate for the serial port (COM1 or COM2) used for the communication.
'   Input arguments:
'   "baud"      the baud rate: B9600, B19200, B38400, B56000, B115200;
'   Returns:
'        1 - successful;
'        0 - fail;
  
  
Declare Function xonxoff Lib "monwin32.dll" Alias "_xonxoff@4" (ByVal status As Long) As Long

'   Sends the "Enable/Disable XON-XOFF handshake" command to the MON24x command interpreter.
'   Input arguments:
'        "status"        1 enables the handshake , other value disables the handshake
'   Returns:
'        1 - successful;
'        0 - fail;

Declare Function check_ack Lib "monwin32.dll" Alias "_check_ack@4" (ByVal status As Long) As Long

'   Sends the "Enable/Disable MCK24x checksum and acknowledge protocol" command
'   to the MON24x command interpreter.
'   Input arguments:
'        "status"        1 enables the protocol, other value disables the protocol
'   Returns:
'        1 - successful;
'        0 - fail;

Declare Function setB0 Lib "monwin32.dll" Alias "_setB0@4" (ByVal status As Long) As Long
    
'   Sends "Set block B0 as PM/DM command" to the DSP monitor.
'   Input arguments:
'       "status"        1 sets B0 in DM space, other value sets B0 in PM space;
'   Returns:
'        1 - successful;
'        0 - fail;

'****************************************************************************
'    Low level communication functions
'***************************************************************************/

Declare Function send_char Lib "monwin32.dll" Alias "_send_char@4" (ByVal data As Byte) As Long

'   Transmits to the DSP board one character/byte, through the serial port of the PC.
'   Input arguments:
'        "data"          data to be sent;
'   Returns:
'        1 - successful;
'        0 - fail;
        
Declare Function get_char Lib "monwin32.dll" Alias "_get_char@4" (ByRef data As Byte) As Long

'   Gets the oldest character/byte received on the PC in the reception buffer,
'   from the DSP board.
'   Input arguments:
'       "data"      the data read from reception buffer;
'   Returns:
'        1 - successful;
'        0 - fail;
 
Declare Function get_char_nowait Lib "monwin32.dll" Alias "_get_char_nowait@4" (ByRef data As Byte) As Long

'    Gets the oldest character/byte received on the PC in the reception buffer,
'    from the DSP board. Do not wait for character.
'    Input arguments:
'        "data"      pointer to data read from reception buffer;
'    Returns:
'        1 - successful;
'        0 - fail;

'****************************************************************************
'    High level communication function
'****************************************************************************/
Declare Function set_address Lib "monwin32.dll" Alias "_set_address@8" (ByVal addr As Integer, ByVal mem_type As Long) As Long

'   Sends the "Set current PM/DM address" command to the MON240 command interpreter.
'   The next read/write monitor command will execute starting from the current PM/DM address.
'   Input arguments:
'        "addr"          new current PM/DM address;
'        "mem_type"      memory type: 0 : program memory (PM), 1 : data memory (DM);
'   Returns:
'        1 - successful;
'        0 - fail;

Declare Function send_data Lib "monwin32.dll" Alias "_send_data@12" (ByRef data As Integer, ByVal mem_type As Long, ByVal data_len As Integer) As Long

'   Sends "Write to PM/DM" command to the MON24x command interpreter. A block of data sent
'   from the PC is written in the F24x PM/DM memory starting with the current PM/DM address.
'   After each word sent, the MON24x command interpreter increments the current PM/DM address.
'   Input arguments:
'       "data"      the data block to be sent. 1st sent is data[0], then data[1], etc.
'       "mem_type"  memory type: 0: PM, 1: DM;
'       "data_len"  number of words - 1 of the data block;
'   Returns:
'        0 - successful;
'        1 - fail;
        

Declare Function get_data Lib "monwin32.dll" Alias "_get_data@12" (ByRef data As Integer, ByVal mem_type As Long, ByVal data_len As Integer) As Long

'   Sends the "Read from PM/DM command" to the MON24x command interpreter. A block of data is
'   read from the F24x PM/DM memory beginning with the PM/DM current address and sent to the PC.
'   After each word sent to the PC, the command interpreter increments the PM/DM current address.
'   Input arguments:
'        "data"      the received data block;
'        "mem_type"  the memory type: 0 - PM, 1 - DM
'        "data_len"  number of words - 1 of the data block
'   Returns:
'        0 - successful;
'        1 - fail;

Declare Function run Lib "monwin32.dll" Alias "_run@0" () As Long

'   Sends "Go to PM" command to MON24x command interpreter in order to start the execution
'   of a previously downloaded DSP program.
'   The MON24x DSP monitor executes a branch to the current PM address.
'   Returns:
'        0 - successful;
'        1 - fail;

Declare Function get_dspmon_ver Lib "monwin32.dll" Alias "_get_dspmon_ver@4" (ByRef data As Integer) As Long

'   Sends an internal command to MON24x command interpreter in order to get the current
'   monitor version.
'   The MON24x DSP monitor responds to this command by returning the monitor version.
'   Input arguments:
'        "pVer"      a pointer to the received monitor version.
'   Returns:
'        0 - successful;
'        1 - fail;

Declare Function download_RAM Lib "monwin32.dll" Alias "_download_RAM@20" (ByVal mode As Long, ByRef file_name As String, _
                ByVal pfReport As Long, ByRef usrData As Variant, ByRef p_entry As Integer) As Long

'       Download a COFF file into RAM memory
'    Input arguments:
'        "mode"      0 - for quiet' download (without any callback report)
'        "file_name" COFF file name to download
'        "p_entry"      pointer to variable that receive the entry point of the program (if any).
'                               May be NULL.
'        "pfReport"     callback report function supplied by caller. May be NULL.
'        "usrData"      user data passed to callback report function. May be NULL.
'    Returns:
'        1 - successful;
'        0 - fail    file error;
'        2 - fail       communication error;

Declare Function download_Flash Lib "monwin32.dll" Alias "_download_Flash@20" (ByRef file_name As String, ByRef pReserved As String, _
                ByVal pfReport As Long, ByRef usrData As Variant, ByRef p_entry As Integer) As Long

'       Download a COFF file into flash memory
'    Input arguments:
'        "mode"      0 - for quiet' download (without any callback report)
'        "file_name" COFF file name to download
'        "pReserved"    must be NULL
'        "p_entry"      pointer to variable that receive the entry point of the program (if any)
'                               may be NULL
'        "pfReport"     callback report function supplied by caller.
'        "usrData"      user data passed to callback report function.
'    Returns:
'        1 - successful;
'        0 - fail    file error;
'        2 - fali       communication error;




